@@ -1,10 +1,8 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.pool import Pool
-from . import account
-from . import party
-from . import reporting_tax
-from . import account_payment
+
+from . import account, account_payment, company, party, reporting_tax
 
 
 def register():
@@ -15,6 +13,7 @@ def register():
         account.TaxTemplate,
         account.Tax,
         account.Invoice,
+        company.Company,
         party.Party,
         party.Identifier,
         reporting_tax.ESVATList,
@@ -33,6 +32,7 @@ def register():
         reporting_tax.VATBookReport,
         module='account_es', type_='report')
     Pool.register(
+        account.CreateChart,
         reporting_tax.PrintAEAT,
         module='account_es', type_='wizard')
     Pool.register(
