@@ -27,7 +27,7 @@ class Identifier(metaclass=PoolMeta):
     def es_country(self):
         if self.type == 'eu_vat':
             return self.code[:2]
-        if self.type in {'es_cif', 'es_dni', 'es_nie', 'es_nif'}:
+        if self.type in {'es_cif', 'es_dni', 'es_nie', 'es_vat'}:
             return 'ES'
 
     def es_code(self):
